gchecky.model.order_adjustment_t

Package gchecky :: Module model :: Class order_adjustment_t |
[hide private]
[frames] | no frames]

# Class order_adjustment_t

source code

    object --+
             |
     gxml.Node --+
                 |
                order_adjustment_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| adjustment_total = `Node:PATH(adjustment-total):OPT:{ price_t }`
| merchant_calculation_successful = `gxml.Boolean('merchant-calcu`...``
| merchant_codes = `Node:PATH(merchant-codes):OPT:{ merchant_code`...``
| shipping = `Node:PATH(shipping):OPT:{ shipping_in_order_adjustm`...``
| total_tax = `Node:PATH(total-tax):OPT:{ price_t }`
| _fields = ``{``'``adjustment_total``'``:` Node:PATH(adjustment-total):OPT`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### merchant_calculation_successful Value:
      gxml.Boolean('merchant-calculation-successful', required= False)

  ### merchant_codes Value:
      Node:PATH(merchant-codes):OPT:{ merchant_codes_t }

  ### shipping Value:
      Node:PATH(shipping):OPT:{ shipping_in_order_adjustment_t }

  ### _fields list of meta-Fields of this class. Value:
      {'adjustment_total': Node:PATH(adjustment-total):OPT:{ price_t },
       'merchant_calculation_successful': ??,
       'merchant_codes': Node:PATH(merchant-codes):OPT:{ merchant_codes_t },
       'shipping': Node:PATH(shipping):OPT:{ shipping_in_order_adjustment_t
      },
       'total_tax': Node:PATH(total-tax):OPT:{ price_t }}